searchData={"items":[{"type":"module","title":"Domainatrex","doc":"Documentation for Domainatrex","ref":"Domainatrex.html"},{"type":"module","title":"Examples - Domainatrex","doc":"iex> Domainatrex.parse(\"someone.com\")\n    {:ok, %{domain: \"someone\", subdomain: \"\", tld: \"com\"}}\n\n    iex> Domainatrex.parse(\"blog.someone.id.au\")\n    {:ok, %{domain: \"someone\", subdomain: \"blog\", tld: \"id.au\"}}\n\n    iex> Domainatrex.parse(\"zen.s3.amazonaws.com\")\n    {:ok, %{domain: \"s3\", subdomain: \"zen\", tld: \"amazonaws.com\"}}","ref":"Domainatrex.html#module-examples"},{"type":"function","title":"Domainatrex.parse/1","doc":"","ref":"Domainatrex.html#parse/1"},{"type":"extras","title":"Overview","doc":"# Domainatrex\n\n> Domainatrex is a TLD parsing library for Elixir, using the Public Suffix list\n\n[![hex.pm version](https://img.shields.io/hexpm/v/domainatrex.svg)](https://hex.pm/packages/domainatrex) [![hex.pm downloads](https://img.shields.io/hexpm/dt/domainatrex.svg)](https://hex.pm/packages/domainatrex) [![License](http://img.shields.io/badge/license-MIT-brightgreen.svg)](http://opensource.org/licenses/MIT)\n\n### [Read the docs](https://hexdocs.pm/domainatrex)","ref":"overview.html"},{"type":"extras","title":"Installation - Overview","doc":"Add the following to your `mix.exs`\n\n```elixir\ndefp deps do\n  [\n    {:domainatrex, \"~> 3.0\"},\n  ]\n```","ref":"overview.html#installation"},{"type":"extras","title":"Usage - Overview","doc":"`Domainatrex` should be able to handle all valid hostnames, it uses the\n[Public Suffix List](https://publicsuffix.org/list/) and is heavily inspired by the fantastic\n[Domainatrix](https://github.com/pauldix/domainatrix) library for Ruby\n\n```elixir\niex> Domainatrex.parse(\"someone.com\")\n{:ok, %{domain: \"someone\", subdomain: \"\", tld: \"com\"}}\n\niex> Domainatrex.parse(\"blog.someone.id.au\")\n{:ok, %{domain: \"someone\", subdomain: \"blog\", tld: \"id.au\"}}\n```","ref":"overview.html#usage"},{"type":"extras","title":"Configuration - Overview","doc":"For maximum performance, `Domainatrex` reads the list of all known top-level domains at compile\ntime. Likewise, by default, the package will attempt to fetch the latest list of TLDs from the\nweb before falling back to a local (potentially out of date) copy. You can configure this behavior\nin your `config.exs` as follows:\n\n- `:fetch_latest`: A Boolean flag to determine whether `Domainatrex` should try to fetch the\n  latest list of public suffixes at compile time; default is `true`\n- `:public_suffix_list_url`: A charlist URL to the latest public suffix file that `Domainatrex`\n  will try to fetch at compile time; default is\n  `'https://raw.githubusercontent.com/publicsuffix/list/master/public_suffix_list.dat'`\n- `:fallback_local_copy`: The path to the local suffix file that `Domainatrex` will use if it\n  wasn't able to fetch a fresh file from the URL, or if fetching updated files was disabled;\n  default is the `\"lib/public_suffix_list.dat\"` file included in the package.\n\nHere's a complete example of how you might customize this behavior in your `config.exs`:\n\n```elixir\nconfig :domainatrex,\n  # Explicitly allow compile-time HTTP request to fetch the latest list of TLDs (default)\n  fetch_latest: true,\n  # Download the public suffix list from the official source (not necessarily tested with Domainatrex!)\n  public_suffix_list_url: 'https://publicsuffix.org/list/public_suffix_list.dat',\n  fallback_local_copy: \"priv/my_app_custom_suffix_list.dat\"\n```","ref":"overview.html#configuration"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"3.0.5 - Changelog","doc":"- FIX: when download fails use local fallback [@Sgiath](https://github.com/sgiath)\n- FEAT: add update script [@Sgiath](https://github.com/sgiath)\n- Update dependencies [@Sgiath](https://github.com/Sgiath)\n- Add Nix flake setup [@Sgiath](https://github.com/Sgiath)\n- Add LICENSE file [@Sgiath](https://github.com/Sgiath)","ref":"changelog.html#3-0-5"},{"type":"extras","title":"3.0.4 - Changelog","doc":"- Fix issue with new, even longer domains from public_suffix_list.dat [@Sgiath](https://github.com/Sgiath)","ref":"changelog.html#3-0-4"},{"type":"extras","title":"3.0.3 - Changelog","doc":"- Fix issue with new, longer domains from public_suffix_list.dat [@fabiokr](https://github.com/fabiokr)","ref":"changelog.html#3-0-3"},{"type":"extras","title":"3.0.1 - Changelog","doc":"- Resolve warnings about SSL and `Mix.Config` being deprecated.","ref":"changelog.html#3-0-1"},{"type":"extras","title":"3.0.0 - Changelog","doc":"- Breaking change: default to including private domains. `:include_private == false` is still\n  respected (but defaults to false), and a new env var `:icann_only` is added and defaults to\n  false.","ref":"changelog.html#3-0-0"},{"type":"extras","title":"2.4.0 - Changelog","doc":"- Support disabling compile time http request with `:fetch_latest` config (thanks @s3cur3 for\n  the PR!)","ref":"changelog.html#2-4-0"},{"type":"extras","title":"2.3.0 - Changelog","doc":"- Bump deps","ref":"changelog.html#2-3-0"},{"type":"extras","title":"2.2.0 - Changelog","doc":"- Use `Logger` for logging","ref":"changelog.html#2-2-0"},{"type":"extras","title":"2.1.4 - Changelog","doc":"- Pin a version of `nimble_parsec` to fix a compilation error on `makeup` (`makeup` has fixed\n  this downstream, so when `ex_doc` updates `makeup`, this will no longer be required)","ref":"changelog.html#2-1-4"},{"type":"extras","title":"2.1.3 - Changelog","doc":"- Merge a couple of minor PRs","ref":"changelog.html#2-1-3"},{"type":"extras","title":"2.1.2 - Changelog","doc":"- Improve tests and docs slightly","ref":"changelog.html#2-1-2"},{"type":"extras","title":"2.1.1 - Changelog","doc":"- Privatize `Domainatrex.match/n` and `Domainatrex.format_response/2` as they are only ever\n  intended for internal use","ref":"changelog.html#2-1-1"},{"type":"extras","title":"2.1.0 - Changelog","doc":"- Better handle private domains. Private domains like `*.s3.amazonaws.com` are technically\n  classed as TLDs (to my understanding?), it doesn't make a lot of sense to parse them this way.\n- Fetch a new copy of the public suffix list from The Internet on compile, falling back to a\n  (now updated!) local copy.","ref":"changelog.html#2-1-0"},{"type":"extras","title":"2.0.0 - Changelog","doc":"- Change the API from returning explicit results to {:ok, result} or {:error, result}. This is to\n  be more uniform with other libraries I use and for better `with` usage. Sorry if this fucks up\n  your day.","ref":"changelog.html#2-0-0"},{"type":"extras","title":"1.0.1 - Changelog","doc":"- Fully update the tests to reflect changes in `2.0.0` (thanks for the PR @pbonney!)","ref":"changelog.html#1-0-1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}